==> financial-settlement-client-0.1.237-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/SmallOrderInvoiceRelationFeignApi.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-08-31
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.SmallOrderInvoiceRelation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface SmallOrderInvoiceRelationFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/smallOrderInvoiceRelation/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param smallOrderInvoiceRelation ${table.comment}
   * @return R
   */
  @PostMapping("/smallOrderInvoiceRelation/add")
  public R save(@RequestBody SmallOrderInvoiceRelation smallOrderInvoiceRelation);

  /**
   * 修改${table.comment}
   * @param smallOrderInvoiceRelation ${table.comment}
   * @return R
   */
  @PostMapping("/smallOrderInvoiceRelation/update")
  public R updateById(@RequestBody SmallOrderInvoiceRelation smallOrderInvoiceRelation);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/smallOrderInvoiceRelation/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> financial-settlement-client-0.1.442-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/SmallOrderInvoiceRelationFeignApi.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-11-22
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.SmallOrderInvoiceRelation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface SmallOrderInvoiceRelationFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/smallOrderInvoiceRelation/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param smallOrderInvoiceRelation ${table.comment}
   * @return R
   */
  @PostMapping("/smallOrderInvoiceRelation/add")
  public R save(@RequestBody SmallOrderInvoiceRelation smallOrderInvoiceRelation);

  /**
   * 修改${table.comment}
   * @param smallOrderInvoiceRelation ${table.comment}
   * @return R
   */
  @PostMapping("/smallOrderInvoiceRelation/update")
  public R updateById(@RequestBody SmallOrderInvoiceRelation smallOrderInvoiceRelation);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/smallOrderInvoiceRelation/del/{id}" )
  public R removeById(@PathVariable Long id);

}
